pub struct DeltaTableMetadata {
pub etag: String,
pub table_type: DeltaTableType,
pub table_uuid: String,
pub location: String,
pub created_time: i64,
pub updated_time: i64,
pub columns: DeltaStructType,
pub partition_columns: Option<Vec<String>>,
pub properties: BTreeMap<String, String>,
pub last_commit_version: Option<i64>,
pub last_commit_timestamp_ms: Option<i64>,
}Expand description
Complete table metadata.
Fields
etag: StringEntity tag for optimistic concurrency control.
table_type: DeltaTableTypetable_uuid: Stringlocation: Stringcreated_time: i64updated_time: i64columns: DeltaStructTypepartition_columns: Option<Vec<String>>properties: BTreeMap<String, String>last_commit_version: Option<i64>The version of the last commit that changed table metadata
(delta.lastUpdateVersion).
last_commit_timestamp_ms: Option<i64>Timestamp of the last commit that changed table metadata, in epoch
milliseconds (delta.lastCommitTimestamp).